@@ -11,6 +11,10 @@ METADATA_DIR="${REPO_DIR}/deploy/metadata/performance-addon-operator"
 
 IMAGE_BUILD_CMD=${IMAGE_BUILD_CMD:-podman}
 
-CSV_VERSION=${CSV_VERSION:-"4.6.2"}
-PREV_CSV_VERSION=${PREV_CSV_VERSION:-"4.5.0"}
-CSV_CHANNEL=${CSV_CHANNEL:-"4.6"}
+CSV_VERSION=${CSV_VERSION:-"4.7.0"}
+PREV_CSV_VERSION=${PREV_CSV_VERSION:-"4.6.0"}
+CSV_CHANNEL=${CSV_CHANNEL:-"4.7"}
+
+MIN_KUBE_VERSION=${MIN_KUBE_VERSION:-"1.19.0"}
+
+ANNOTATIONS_FILE="${REPO_DIR}/hack/annotations.json"
